"""Q-functions which use NumPy as a numerical backend."""
from garage.np.q_functions.q_function import QFunction

__all__ = ['QFunction']
